#[non_exhaustive]pub struct PassingInfo {
pub passing_detected: bool,
pub index: usize,
pub num_steps: usize,
pub start_distance: Length,
pub distance: Length,
pub start_speed: Velocity,
pub speed: Velocity,
pub time_step_duration: Time,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.passing_detected: boolTrue if first cycle passes the second; NOTE: was has_collision
index: usizethe index where first cycle passes the second; NOTE: was idx
num_steps: usizethe number of time-steps until index from i
start_distance: Lengththe starting distance of the first cycle at i
distance: Lengththe distance traveled of the second cycle when the first passes
start_speed: Velocitythe starting speed of the first cycle at i
speed: Velocitythe speed of the second cycle when first passes
time_step_duration: Timethe (assumed constant) time step duration throughout the passing investigation
Implementations
Sourceimpl PassingInfo
impl PassingInfo
Sourcepub fn from(
cyc: &Cycle,
cyc_ref: &Cycle,
i: usize,
distance_tolerance: Option<Length>,
) -> Self
pub fn from( cyc: &Cycle, cyc_ref: &Cycle, i: usize, distance_tolerance: Option<Length>, ) -> Self
Create a new PassingInfo struct from a cycle and reference cycle.
- cyc: the cycle to detect passing for
- cyc0: the reference cycle / lead vehicle / shadow cycle to compare cyc with
- i: the time-step index for the start of consideration
- distance_tolerance: the distance away from the lead vehicle at or above which we consider ourselves “deviated” or “no longer following” the reference trace
RETURN: a PassingInfo structure