#[non_exhaustive]pub struct Air {}Implementations
Sourceimpl Air
impl Air
Sourcepub fn get_density(
te_air: Option<Temperature>,
h: Option<Length>,
) -> MassDensity
pub fn get_density( te_air: Option<Temperature>, h: Option<Length>, ) -> MassDensity
Returns density of air with computational optimizations for default inputs
Source: https://www.grc.nasa.gov/WWW/K-12/rocket/atmosmet.html
Note that if None is passed for either argument, function evaluation should be faster
Equations used
- T = 15.04 - 0.00649 * h
- p = 101.29 * ((T + 273.1) / 288.08) ^ 5.256
Arguments
te_air- ambient temperature of air, defaults to 22 Ch- elevation above sea level, defaults to 180 m
Sourcepub fn get_therm_cond(te_air: Temperature) -> Result<ThermalConductivity>
pub fn get_therm_cond(te_air: Temperature) -> Result<ThermalConductivity>
Sourcepub fn get_specific_heat_cp(te_air: Temperature) -> Result<SpecificHeatCapacity>
pub fn get_specific_heat_cp(te_air: Temperature) -> Result<SpecificHeatCapacity>
Sourcepub fn get_specific_enthalpy(te_air: Temperature) -> Result<SpecificEnergy>
pub fn get_specific_enthalpy(te_air: Temperature) -> Result<SpecificEnergy>
Sourcepub fn get_specific_energy(te_air: Temperature) -> Result<SpecificEnergy>
pub fn get_specific_energy(te_air: Temperature) -> Result<SpecificEnergy>
Sourcepub fn get_pr(te_air: Temperature) -> Result<Ratio>
pub fn get_pr(te_air: Temperature) -> Result<Ratio>
Sourcepub fn get_dyn_visc(te_air: Temperature) -> Result<DynamicViscosity>
pub fn get_dyn_visc(te_air: Temperature) -> Result<DynamicViscosity>
Sourcepub fn get_te_from_h(h: SpecificEnergy) -> Result<Temperature>
pub fn get_te_from_h(h: SpecificEnergy) -> Result<Temperature>
Sourcepub fn get_te_from_u(u: SpecificEnergy) -> Result<Temperature>
pub fn get_te_from_u(u: SpecificEnergy) -> Result<Temperature>