Macro fastsim_core::format_dbg
source · macro_rules! format_dbg { ($dbg_expr:expr) => { ... }; () => { ... }; }
Generates a String similar to output of dbg but without printing
macro_rules! format_dbg { ($dbg_expr:expr) => { ... }; () => { ... }; }
Generates a String similar to output of dbg but without printing