macro_rules! init_opt_default {
($obj:ident, $fieldname:ident, $def_val:expr) => { ... };
}Expand description
Makes it so that optional parameters get set in the Init::init call
macro_rules! init_opt_default {
($obj:ident, $fieldname:ident, $def_val:expr) => { ... };
}Makes it so that optional parameters get set in the Init::init call