pub struct AdjCoefMap {
pub adj_coef_map: HashMap<String, AdjCoef>,
}Fields
adj_coef_map: HashMap<String, AdjCoef>Trait Implementations
Sourceimpl ApproxEq for AdjCoefMap
impl ApproxEq for AdjCoefMap
Sourceimpl Clone for AdjCoefMap
impl Clone for AdjCoefMap
Sourcefn clone(&self) -> AdjCoefMap
fn clone(&self) -> AdjCoefMap
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdjCoefMap
impl Debug for AdjCoefMap
Sourceimpl Default for AdjCoefMap
impl Default for AdjCoefMap
Sourcefn default() -> AdjCoefMap
fn default() -> AdjCoefMap
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AdjCoefMap
impl<'de> Deserialize<'de> for AdjCoefMap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AdjCoefMap
impl PartialEq for AdjCoefMap
Sourceimpl SerdeAPI for AdjCoefMap
impl SerdeAPI for AdjCoefMap
const ACCEPTED_BYTE_FORMATS: &'static [&'static str] = _
const ACCEPTED_STR_FORMATS: &'static [&'static str] = _
const RESOURCE_PREFIX: &'static str = ""
const CACHE_FOLDER: &'static str = ""
Sourcefn list_resources() -> Vec<String>
fn list_resources() -> Vec<String>
List available (compiled) resources (stored in the rust binary) Read more
Sourcefn from_resource<P: AsRef<Path>>(filepath: P, skip_init: bool) -> Result<Self>
fn from_resource<P: AsRef<Path>>(filepath: P, skip_init: bool) -> Result<Self>
Read (deserialize) an object from a resource file packaged with the
fastsim-core crate Read moreSourcefn to_file<P: AsRef<Path>>(&self, filepath: P) -> Result<()>
fn to_file<P: AsRef<Path>>(&self, filepath: P) -> Result<()>
Write (serialize) an object to a file.
Supported file extensions are listed in
ACCEPTED_BYTE_FORMATS.
Creates a new file if it does not already exist, otherwise truncates the existing file. Read morefn to_writer<W: Write>(&self, wtr: W, format: &str) -> Result<()>
Sourcefn from_file<P: AsRef<Path>>(filepath: P, skip_init: bool) -> Result<Self>
fn from_file<P: AsRef<Path>>(filepath: P, skip_init: bool) -> Result<Self>
Read (deserialize) an object from a file.
Supported file extensions are listed in
ACCEPTED_BYTE_FORMATS. Read moreSourcefn to_str(&self, format: &str) -> Result<String>
fn to_str(&self, format: &str) -> Result<String>
Write (serialize) an object into a string Read more
Sourcefn from_str<S: AsRef<str>>(
contents: S,
format: &str,
skip_init: bool,
) -> Result<Self>
fn from_str<S: AsRef<str>>( contents: S, format: &str, skip_init: bool, ) -> Result<Self>
Read (deserialize) an object from a string Read more
Sourcefn from_reader<R: Read>(rdr: R, format: &str, skip_init: bool) -> Result<Self>
fn from_reader<R: Read>(rdr: R, format: &str, skip_init: bool) -> Result<Self>
Deserialize an object from anything that implements
std::io::Read Read moreSourcefn from_json<S: AsRef<str>>(json_str: S, skip_init: bool) -> Result<Self>
fn from_json<S: AsRef<str>>(json_str: S, skip_init: bool) -> Result<Self>
Read (deserialize) an object to a JSON string Read more
Sourcefn from_yaml<S: AsRef<str>>(yaml_str: S, skip_init: bool) -> Result<Self>
fn from_yaml<S: AsRef<str>>(yaml_str: S, skip_init: bool) -> Result<Self>
Read (deserialize) an object from a YAML string Read more
fn to_toml(&self) -> Result<String>
fn from_toml<S: AsRef<str>>(toml_str: S, skip_init: bool) -> Result<Self>
Sourcefn from_url<S: AsRef<str>>(url: S, skip_init: bool) -> Result<Self>
fn from_url<S: AsRef<str>>(url: S, skip_init: bool) -> Result<Self>
Instantiates an object from a url. Accepts yaml and json file types Read more
Sourcefn to_cache<P: AsRef<Path>>(&self, file_path: P) -> Result<()>
fn to_cache<P: AsRef<Path>>(&self, file_path: P) -> Result<()>
Takes an instantiated Rust object and saves it in the FASTSim data directory in
a rust_objects folder.
WARNING: If there is a file already in the data subdirectory with the same name, it will be replaced by the new file. Read more
WARNING: If there is a file already in the data subdirectory with the same name, it will be replaced by the new file. Read more
Sourcefn from_cache<P: AsRef<Path>>(file_path: P, skip_init: bool) -> Result<Self>
fn from_cache<P: AsRef<Path>>(file_path: P, skip_init: bool) -> Result<Self>
Instantiates a Rust object from the subdirectory within the FASTSim data
directory corresponding to the Rust Object (“vehices” for a RustVehice,
“cycles” for a RustCycle, and the root folder of the data directory for
all other objects). Read more
Sourceimpl Serialize for AdjCoefMap
impl Serialize for AdjCoefMap
impl StructuralPartialEq for AdjCoefMap