pub enum TraceMissOptions {
Allow,
AllowChecked,
Error,
Correct,
}Variants
Allow
Allow trace miss without any fanfare
AllowChecked
Allow trace miss within error tolerance
Error
Error out when trace miss happens
Correct
Correct trace miss with driver model that catches up
Implementations
Sourceimpl TraceMissOptions
impl TraceMissOptions
Sourcepub const fn is_allow(&self) -> bool
pub const fn is_allow(&self) -> bool
Returns true if this value is of type Allow. Returns false otherwise
Sourcepub const fn is_allow_checked(&self) -> bool
pub const fn is_allow_checked(&self) -> bool
Returns true if this value is of type AllowChecked. Returns false otherwise
Sourcepub const fn is_error(&self) -> bool
pub const fn is_error(&self) -> bool
Returns true if this value is of type Error. Returns false otherwise
Sourcepub const fn is_correct(&self) -> bool
pub const fn is_correct(&self) -> bool
Returns true if this value is of type Correct. Returns false otherwise