#[non_exhaustive]pub struct TraceMissTolerance {
pub tol_dist: Length,
pub tol_dist_frac: Ratio,
pub tol_speed: Velocity,
pub tol_speed_frac: Ratio,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tol_dist: Lengthif the vehicle falls this far behind trace in terms of absolute difference and TraceMissOptions::is_allow_checked, fail
tol_dist_frac: Ratioif the vehicle falls this far behind trace in terms of fractional difference and TraceMissOptions::is_allow_checked, fail
tol_speed: Velocityif the vehicle falls this far behind instantaneous speed and TraceMissOptions::is_allow_checked, fail
tol_speed_frac: Ratioif the vehicle falls this far behind instantaneous speed in terms of fractional difference and TraceMissOptions::is_allow_checked, fail
Implementations