SimDrive

Struct SimDrive 

#[non_exhaustive]
pub struct SimDrive { pub veh: Vehicle, pub cyc: Cycle, pub sim_params: SimParams, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
veh: Vehiclecyc: Cyclesim_params: SimParams

Implementations

Source

impl SimDrive

pub fn new(veh: Vehicle, cyc: Cycle, sim_params: Option<SimParams>) -> Self

pub fn walk(&mut self) -> Result<()>

Run vehicle simulation, and, if applicable, apply powertrain-specific corrections:

  • for HEV, set initial SOC to mean of min and max SOC, and then iterate walk until SOC balance is achieved – i.e. initial and final SOC are nearly identical
  • for PHEV, set initial SOC to max SOC, and then simulate once
  • for BEV, set initial SOC to max SOC, and then simulate once
  • for Conv, simulate once
Important Considerations

If you need to run a ReversibleEnergyStorage-equipped vehicle for only one iteration without modifying the initial SOC, then run the Self::walk_once method directly

pub fn walk_once(&mut self) -> Result<()>

Run vehicle simulation once

pub fn calc_dvdd(&self, speed_m_per_s: f64, grade: f64) -> Result<f64>

Calculates the derivative dv/dd (change in speed by change in distance)

  • speed_m_per_s: the speed at which to evaluate dv/dd (m/s)
  • grade: the road grade as a decimal fraction

RETURN: number, the dv/dd for these conditions

pub fn solve_step(&mut self) -> Result<()>

Solves current time step

pub fn set_pwr_prop_for_speed( &mut self, speed: Velocity, speed_prev: Velocity, dt: Time, ) -> Result<()>

Sets power required for given prescribed speed

Arguments
  • speed: prescribed or achieved speed
  • dt: simulation time step size
pub fn set_ach_speed(&mut self, cyc_speed: Velocity, dt: Time) -> Result<()>

Sets achieved speed based on known current max power

Arguments
  • cyc_speed: prescribed speed
  • dt: simulation time step size
pub fn to_fastsim2(&self) -> Result<RustSimDrive>

pub fn clear(&mut self)