#[non_exhaustive]pub struct SimParams {
pub ach_speed_max_iter: u32,
pub ach_speed_tol: Ratio,
pub ach_speed_solver_gain: f64,
pub trace_miss_tol: TraceMissTolerance,
pub trace_miss_opts: TraceMissOptions,
pub trace_miss_correct_max_steps: u32,
pub f2_const_air_density: bool,
pub ambient_thermal_soak: bool,
}Expand description
Solver parameters
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ach_speed_max_iter: u32max number of iterations allowed in setting achieved speed when trace cannot be achieved
ach_speed_tol: Ratiotolerance in change in speed guess in setting achieved speed when trace cannot be achieved
ach_speed_solver_gain: f64Newton method gain for setting achieved speed
trace_miss_tol: TraceMissToleranceWhen implemented, this will set the tolerance on how much trace miss is allowed
trace_miss_opts: TraceMissOptionstrace_miss_correct_max_steps: u32the maximum number of steps in which to re-rendezvous with reference trace after a trace miss. Note: this field only applies when trace_miss_opts is set to TraceMissOptions::Correct. Note: must be 2 or greater. Defaults to 6.
f2_const_air_density: boolwhether to use FASTSim-2 style air density
ambient_thermal_soak: boolif true, vehicle is totally inactive except for thermal models