Trait Step

pub trait Step {
    // Required methods
    fn step<F: Fn() -> String>(&mut self, loc: F) -> Result<()>;
    fn reset_step<F: Fn() -> String>(&mut self, loc: F) -> Result<()>;
}
Trait that provides method for incrementing i field of this and all contained structs, recursively

Required Methods

fn step<F: Fn() -> String>(&mut self, loc: F) -> Result<()>

Increments i field of this and all contained structs, recursively

Arguments
  • loc: closure that returns file and line number where called
fn reset_step<F: Fn() -> String>(&mut self, loc: F) -> Result<()>

Resets i field of this and all contained structs, recursively

Arguments
  • loc: closure that returns file and line number where called

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors