TrackedState

Struct TrackedState 

pub struct TrackedState<T>(/* private fields */);
Struct for storing state variable and ensuring one mutation per initialization or reset – i.e. one mutation per time step

Implementations

Source

impl<T> TrackedState<T>
where T: Debug + Clone + PartialEq + Default,

Provides methods to guarantee that states are updated once and only once per time step

pub fn new(value: T) -> Self

pub fn inner(&self) -> &T

Returns a reference to the inner value without freshness checking. Intended for use with #[serde(serialize_with)] helpers.

pub fn mark_stale(&mut self)

Reset the tracked state to [State::Stale] for the next update after verifying that is has been updated

pub fn update<F: Fn() -> String>(&mut self, value: T, loc: F) -> Result<()>

Update the value of the tracked state after verifying that it has not already been updated

Arguments
  • value: new value
  • loc: closure that returns file and line number where called
pub fn update_unchecked<F: Fn() -> String>( &mut self, value: T, _loc: F, ) -> Result<()>

Update the value of the tracked state without verifying that it has not already been updated – to be used sparingly!

Arguments
  • value: new value
  • loc: closure that returns file and line number where called
pub fn get_fresh<F: Fn() -> String>(&self, loc: F) -> Result<&T>

Check that value has been updated and then return as a result

Arguments
  • loc: call site location filename and line number
pub fn get_stale<F: Fn() -> String>(&self, loc: F) -> Result<&T>

Check that value has not been updated and then return as a result

Arguments
  • loc: call site location filename and line number
Source

impl<T: Debug + Clone + PartialEq + Default + AddAssign> TrackedState<T>

State methods that allow for +=

pub fn increment<F: Fn() -> String>(&mut self, value: T, loc: F) -> Result<()>

Update the value of the tracked state

Arguments
  • value: new value
  • loc: closure that returns file and line number where called