Trait TrackedStateMethods

pub trait TrackedStateMethods {
    // Required methods
    fn mark_fresh<F: Fn() -> String>(&mut self, loc: F) -> Result<()>;
    fn check_and_reset<F: Fn() -> String>(&mut self, loc: F) -> Result<()>;
}
Methods for manipulating states that need to be implemented up the hierarchy

Required Methods

fn mark_fresh<F: Fn() -> String>(&mut self, loc: F) -> Result<()>

Mark states as [State::Fresh]

Arguments
  • loc: closure that returns file and line number where called
fn check_and_reset<F: Fn() -> String>(&mut self, loc: F) -> Result<()>

Ensure [State::Fresh] and reset to [State::Stale]

Arguments
  • loc: closure that returns file and line number where called

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl TrackedStateMethods for CabinOption

Source

impl TrackedStateMethods for HEVPowertrainControls

Source

impl TrackedStateMethods for HVACOption

Source

impl TrackedStateMethods for FuelConverterThermalOption

Source

impl TrackedStateMethods for RESThermalOption

Source

impl TrackedStateMethods for PowertrainType

Source

impl TrackedStateMethods for SimDrive

Source

impl TrackedStateMethods for BatteryElectricVehicle

Source

impl TrackedStateMethods for LumpedCabin

Source

impl TrackedStateMethods for LumpedCabinState

Source

impl TrackedStateMethods for ConventionalVehicle

Source

impl TrackedStateMethods for HybridElectricVehicle

Source

impl TrackedStateMethods for RESGreedyWithDynamicBuffers

Source

impl TrackedStateMethods for RGWDBState

Source

impl TrackedStateMethods for HVACSystemForLumpedCabin

Source

impl TrackedStateMethods for HVACSystemForLumpedCabinState

Source

impl TrackedStateMethods for HVACSystemForLumpedCabinAndRES

Source

impl TrackedStateMethods for HVACSystemForLumpedCabinAndRESState

Source

impl TrackedStateMethods for ElectricMachine

Source

impl TrackedStateMethods for ElectricMachineState

Source

impl TrackedStateMethods for FuelConverter

Source

impl TrackedStateMethods for FuelConverterState

Source

impl TrackedStateMethods for FuelConverterThermal

Source

impl TrackedStateMethods for FuelConverterThermalState

Source

impl TrackedStateMethods for RESLumpedThermal

Source

impl TrackedStateMethods for RESLumpedThermalState

Source

impl TrackedStateMethods for ReversibleEnergyStorage

Source

impl TrackedStateMethods for ReversibleEnergyStorageState

Source

impl TrackedStateMethods for Transmission

Source

impl TrackedStateMethods for TransmissionState

Source

impl TrackedStateMethods for Vehicle

Source

impl TrackedStateMethods for VehicleState

Source

impl<T> TrackedStateMethods for TrackedState<T>
where T: Debug + Clone + PartialEq + Default,