RESGreedyWithDynamicBuffers

Struct RESGreedyWithDynamicBuffers 

#[non_exhaustive]
pub struct RESGreedyWithDynamicBuffers {
Show 15 fields pub speed_soc_disch_buffer: Option<Velocity>, pub speed_soc_disch_buffer_coeff: Option<Ratio>, pub speed_soc_fc_on_buffer: Option<Velocity>, pub speed_soc_fc_on_buffer_coeff: Option<Ratio>, pub speed_soc_regen_buffer: Option<Velocity>, pub speed_soc_regen_buffer_coeff: Option<Ratio>, pub fc_min_time_on: Option<Time>, pub speed_fc_forced_on: Option<Velocity>, pub frac_pwr_demand_fc_forced_on: Option<Ratio>, pub frac_of_most_eff_pwr_to_run_fc: Option<Ratio>, pub save_interval: Option<usize>, pub temp_fc_forced_on: Option<Temperature>, pub temp_fc_allowed_off: Option<Temperature>, pub state: RGWDBState, pub history: RGWDBStateHistoryVec,
}
Greedily uses ReversibleEnergyStorage with buffers that derate charge and discharge power inside of static min and max SOC range. Also, includes buffer for forcing FuelConverter to be active/on. See Self::init for default values.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
speed_soc_disch_buffer: Option<Velocity>

RES energy delta from minimum SOC corresponding to kinetic energy of vehicle at this speed that triggers ramp down in RES discharge.

speed_soc_disch_buffer_coeff: Option<Ratio>

Coefficient for modifying amount of accel buffer

speed_soc_fc_on_buffer: Option<Velocity>

RES energy delta from minimum SOC corresponding to kinetic energy of vehicle at this speed that triggers FC to be forced on.

speed_soc_fc_on_buffer_coeff: Option<Ratio>

Coefficient for modifying amount of Self::speed_soc_fc_on_buffer

speed_soc_regen_buffer: Option<Velocity>

RES energy delta from maximum SOC corresponding to kinetic energy of vehicle at current speed minus kinetic energy of vehicle at this speed triggers ramp down in RES discharge

speed_soc_regen_buffer_coeff: Option<Ratio>

Coefficient for modifying amount of regen buffer

fc_min_time_on: Option<Time>

Minimum time engine must remain on if it was on during the previous simulation time step.

speed_fc_forced_on: Option<Velocity>

Speed at which FuelConverter is forced on.

frac_pwr_demand_fc_forced_on: Option<Ratio>

Fraction of total aux and powertrain rated power at which FuelConverter is forced on.

frac_of_most_eff_pwr_to_run_fc: Option<Ratio>

Force engine, if on, to run at this fraction of power at which peak efficiency occurs or the required power, whichever is greater. If SOC is below min buffer or engine is otherwise forced on and battery has room to receive charge, engine will run at this level and charge.

save_interval: Option<usize>

Fraction of available charging capacity to use toward running the engine efficiently. Time step interval between saves. 1 is a good option. If None, no saving occurs.

temp_fc_forced_on: Option<Temperature>

temperature at which engine is forced on to warm up

temp_fc_allowed_off: Option<Temperature>

temperature at which engine is allowed to turn off due to being sufficiently warm

state: RGWDBState

current state of control variables

history: RGWDBStateHistoryVec

history of current state