Struct fastsim_core::params::AdjCoef
source · pub struct AdjCoef {
pub city_intercept: f64,
pub city_slope: f64,
pub hwy_intercept: f64,
pub hwy_slope: f64,
}Fields
city_intercept: f64city_slope: f64hwy_intercept: f64hwy_slope: f64Trait Implementations
sourceimpl<'de> Deserialize<'de> for AdjCoef
impl<'de> Deserialize<'de> for AdjCoef
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<AdjCoef> for AdjCoef
impl PartialEq<AdjCoef> for AdjCoef
sourceimpl SerdeAPI for AdjCoef
impl SerdeAPI for AdjCoef
sourcefn to_file(&self, filename: &str) -> Result<(), Error>
fn to_file(&self, filename: &str) -> Result<(), Error>
Save current data structure to file. Method adaptively calls serialization methods
dependent on the suffix of the file given as str. Read more
sourcefn from_file(filename: &str) -> Result<Self, Error>where
for<'de> Self: Sized + Deserialize<'de>,
fn from_file(filename: &str) -> Result<Self, Error>where for<'de> Self: Sized + Deserialize<'de>,
Read from file and return instantiated struct. Method adaptively calls deserialization
methods dependent on the suffix of the file name given as str.
Function returns a dynamic Error Result if it fails. Read more
sourcefn to_bincode(&self) -> Vec<u8>
fn to_bincode(&self) -> Vec<u8>
bincode serialization method.
impl StructuralPartialEq for AdjCoef