Struct fastsim_core::params::AdjCoefMap
source · pub struct AdjCoefMap {
pub adj_coef_map: HashMap<String, AdjCoef>,
}Fields
adj_coef_map: HashMap<String, AdjCoef>Trait Implementations
sourceimpl ApproxEq<AdjCoefMap> for AdjCoefMap
impl ApproxEq<AdjCoefMap> for AdjCoefMap
sourceimpl Clone for AdjCoefMap
impl Clone for AdjCoefMap
sourcefn clone(&self) -> AdjCoefMap
fn clone(&self) -> AdjCoefMap
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AdjCoefMap
impl Debug for AdjCoefMap
sourceimpl Default for AdjCoefMap
impl Default for AdjCoefMap
sourcefn default() -> AdjCoefMap
fn default() -> AdjCoefMap
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for AdjCoefMap
impl<'de> Deserialize<'de> for AdjCoefMap
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<AdjCoefMap> for AdjCoefMap
impl PartialEq<AdjCoefMap> for AdjCoefMap
sourcefn eq(&self, other: &AdjCoefMap) -> bool
fn eq(&self, other: &AdjCoefMap) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl SerdeAPI for AdjCoefMap
impl SerdeAPI for AdjCoefMap
sourcefn to_file(&self, filename: &str) -> Result<(), Error>
fn to_file(&self, filename: &str) -> Result<(), Error>
Save current data structure to file. Method adaptively calls serialization methods
dependent on the suffix of the file given as str. Read more
sourcefn from_file(filename: &str) -> Result<Self, Error>where
for<'de> Self: Sized + Deserialize<'de>,
fn from_file(filename: &str) -> Result<Self, Error>where for<'de> Self: Sized + Deserialize<'de>,
Read from file and return instantiated struct. Method adaptively calls deserialization
methods dependent on the suffix of the file name given as str.
Function returns a dynamic Error Result if it fails. Read more
sourcefn to_bincode(&self) -> Vec<u8>
fn to_bincode(&self) -> Vec<u8>
bincode serialization method.
sourceimpl Serialize for AdjCoefMap
impl Serialize for AdjCoefMap
impl StructuralPartialEq for AdjCoefMap