Struct fastsim_core::params::RustLongParams
source · pub struct RustLongParams {
pub rechg_freq_miles: Vec<f64>,
pub uf_array: Vec<f64>,
pub ld_fe_adj_coef: AdjCoefMap,
}Fields
rechg_freq_miles: Vec<f64>uf_array: Vec<f64>ld_fe_adj_coef: AdjCoefMapTrait Implementations
sourceimpl ApproxEq<RustLongParams> for RustLongParams
impl ApproxEq<RustLongParams> for RustLongParams
sourceimpl Clone for RustLongParams
impl Clone for RustLongParams
sourcefn clone(&self) -> RustLongParams
fn clone(&self) -> RustLongParams
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RustLongParams
impl Debug for RustLongParams
sourceimpl Default for RustLongParams
impl Default for RustLongParams
sourceimpl<'de> Deserialize<'de> for RustLongParams
impl<'de> Deserialize<'de> for RustLongParams
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<RustLongParams> for RustLongParams
impl PartialEq<RustLongParams> for RustLongParams
sourcefn eq(&self, other: &RustLongParams) -> bool
fn eq(&self, other: &RustLongParams) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl SerdeAPI for RustLongParams
impl SerdeAPI for RustLongParams
sourcefn to_file(&self, filename: &str) -> Result<(), Error>
fn to_file(&self, filename: &str) -> Result<(), Error>
Save current data structure to file. Method adaptively calls serialization methods
dependent on the suffix of the file given as str. Read more
sourcefn from_file(filename: &str) -> Result<Self, Error>where
for<'de> Self: Sized + Deserialize<'de>,
fn from_file(filename: &str) -> Result<Self, Error>where for<'de> Self: Sized + Deserialize<'de>,
Read from file and return instantiated struct. Method adaptively calls deserialization
methods dependent on the suffix of the file name given as str.
Function returns a dynamic Error Result if it fails. Read more
sourcefn to_bincode(&self) -> Vec<u8>
fn to_bincode(&self) -> Vec<u8>
bincode serialization method.
sourceimpl Serialize for RustLongParams
impl Serialize for RustLongParams
impl StructuralPartialEq for RustLongParams