Struct fastsim_core::simdrive::RustSimDriveParams
source · pub struct RustSimDriveParams {Show 31 fields
pub favor_grade_accuracy: bool,
pub missed_trace_correction: bool,
pub max_time_dilation: f64,
pub min_time_dilation: f64,
pub time_dilation_tol: f64,
pub max_trace_miss_iters: u32,
pub trace_miss_speed_mps_tol: f64,
pub trace_miss_time_tol: f64,
pub trace_miss_dist_tol: f64,
pub sim_count_max: usize,
pub newton_gain: f64,
pub newton_max_iter: u32,
pub newton_xtol: f64,
pub energy_audit_error_tol: f64,
pub coast_allow: bool,
pub coast_allow_passing: bool,
pub coast_max_speed_m_per_s: f64,
pub coast_brake_accel_m_per_s2: f64,
pub coast_brake_start_speed_m_per_s: f64,
pub coast_start_speed_m_per_s: f64,
pub coast_time_horizon_for_adjustment_s: f64,
pub idm_allow: bool,
pub idm_v_desired_m_per_s: f64,
pub idm_dt_headway_s: f64,
pub idm_minimum_gap_m: f64,
pub idm_delta: f64,
pub idm_accel_m_per_s2: f64,
pub idm_decel_m_per_s2: f64,
pub idm_v_desired_in_m_per_s_by_distance_m: Option<Vec<(f64, f64)>>,
pub max_epa_adj: f64,
pub orphaned: bool,
}Expand description
Struct containing time trace data
Fields
favor_grade_accuracy: boolmissed_trace_correction: boolmax_time_dilation: f64min_time_dilation: f64time_dilation_tol: f64max_trace_miss_iters: u32trace_miss_speed_mps_tol: f64trace_miss_time_tol: f64trace_miss_dist_tol: f64sim_count_max: usizenewton_gain: f64newton_max_iter: u32newton_xtol: f64energy_audit_error_tol: f64coast_allow: boolcoast_allow_passing: boolcoast_max_speed_m_per_s: f64coast_brake_accel_m_per_s2: f64coast_brake_start_speed_m_per_s: f64coast_start_speed_m_per_s: f64coast_time_horizon_for_adjustment_s: f64idm_allow: boolidm_v_desired_m_per_s: f64idm_dt_headway_s: f64idm_minimum_gap_m: f64idm_delta: f64idm_accel_m_per_s2: f64idm_decel_m_per_s2: f64idm_v_desired_in_m_per_s_by_distance_m: Option<Vec<(f64, f64)>>max_epa_adj: f64orphaned: boolTrait Implementations
sourceimpl Clone for RustSimDriveParams
impl Clone for RustSimDriveParams
sourcefn clone(&self) -> RustSimDriveParams
fn clone(&self) -> RustSimDriveParams
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RustSimDriveParams
impl Debug for RustSimDriveParams
sourceimpl Default for RustSimDriveParams
impl Default for RustSimDriveParams
sourceimpl<'de> Deserialize<'de> for RustSimDriveParams
impl<'de> Deserialize<'de> for RustSimDriveParams
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<RustSimDriveParams> for RustSimDriveParams
impl PartialEq<RustSimDriveParams> for RustSimDriveParams
sourcefn eq(&self, other: &RustSimDriveParams) -> bool
fn eq(&self, other: &RustSimDriveParams) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl SerdeAPI for RustSimDriveParams
impl SerdeAPI for RustSimDriveParams
sourcefn to_file(&self, filename: &str) -> Result<(), Error>
fn to_file(&self, filename: &str) -> Result<(), Error>
Save current data structure to file. Method adaptively calls serialization methods
dependent on the suffix of the file given as str. Read more
sourcefn from_file(filename: &str) -> Result<Self, Error>where
for<'de> Self: Sized + Deserialize<'de>,
fn from_file(filename: &str) -> Result<Self, Error>where for<'de> Self: Sized + Deserialize<'de>,
Read from file and return instantiated struct. Method adaptively calls deserialization
methods dependent on the suffix of the file name given as str.
Function returns a dynamic Error Result if it fails. Read more
sourcefn to_bincode(&self) -> Vec<u8>
fn to_bincode(&self) -> Vec<u8>
bincode serialization method.
sourceimpl Serialize for RustSimDriveParams
impl Serialize for RustSimDriveParams
impl StructuralPartialEq for RustSimDriveParams