Struct fastsim_core::simdrivelabel::LabelFe
source · pub struct LabelFe {Show 26 fields
pub veh: RustVehicle,
pub adj_params: AdjCoef,
pub lab_udds_mpgge: f64,
pub lab_hwy_mpgge: f64,
pub lab_comb_mpgge: f64,
pub lab_udds_kwh_per_mi: f64,
pub lab_hwy_kwh_per_mi: f64,
pub lab_comb_kwh_per_mi: f64,
pub adj_udds_mpgge: f64,
pub adj_hwy_mpgge: f64,
pub adj_comb_mpgge: f64,
pub adj_udds_kwh_per_mi: f64,
pub adj_hwy_kwh_per_mi: f64,
pub adj_comb_kwh_per_mi: f64,
pub adj_udds_ess_kwh_per_mi: f64,
pub adj_hwy_ess_kwh_per_mi: f64,
pub adj_comb_ess_kwh_per_mi: f64,
pub net_range_miles: f64,
pub uf: f64,
pub net_accel: f64,
pub res_found: String,
pub phev_calcs: Option<LabelFePHEV>,
pub adj_cs_comb_mpgge: Option<f64>,
pub adj_cd_comb_mpgge: Option<f64>,
pub net_phev_cd_miles: Option<f64>,
pub trace_miss_speed_mph: f64,
}Fields
veh: RustVehicleadj_params: AdjCoeflab_udds_mpgge: f64lab_hwy_mpgge: f64lab_comb_mpgge: f64lab_udds_kwh_per_mi: f64lab_hwy_kwh_per_mi: f64lab_comb_kwh_per_mi: f64adj_udds_mpgge: f64adj_hwy_mpgge: f64adj_comb_mpgge: f64adj_udds_kwh_per_mi: f64adj_hwy_kwh_per_mi: f64adj_comb_kwh_per_mi: f64adj_udds_ess_kwh_per_mi: f64adj_hwy_ess_kwh_per_mi: f64adj_comb_ess_kwh_per_mi: f64net_range_miles: f64uf: f64net_accel: f64res_found: Stringphev_calcs: Option<LabelFePHEV>adj_cs_comb_mpgge: Option<f64>adj_cd_comb_mpgge: Option<f64>net_phev_cd_miles: Option<f64>trace_miss_speed_mph: f64Trait Implementations
sourceimpl<'de> Deserialize<'de> for LabelFe
impl<'de> Deserialize<'de> for LabelFe
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<LabelFe> for LabelFe
impl PartialEq<LabelFe> for LabelFe
sourceimpl SerdeAPI for LabelFe
impl SerdeAPI for LabelFe
sourcefn to_file(&self, filename: &str) -> Result<(), Error>
fn to_file(&self, filename: &str) -> Result<(), Error>
Save current data structure to file. Method adaptively calls serialization methods
dependent on the suffix of the file given as str. Read more
sourcefn from_file(filename: &str) -> Result<Self, Error>where
for<'de> Self: Sized + Deserialize<'de>,
fn from_file(filename: &str) -> Result<Self, Error>where for<'de> Self: Sized + Deserialize<'de>,
Read from file and return instantiated struct. Method adaptively calls deserialization
methods dependent on the suffix of the file name given as str.
Function returns a dynamic Error Result if it fails. Read more
sourcefn to_bincode(&self) -> Vec<u8>
fn to_bincode(&self) -> Vec<u8>
bincode serialization method.
impl StructuralPartialEq for LabelFe