Struct fastsim_core::simdrivelabel::LabelFePHEV
source · pub struct LabelFePHEV {
pub regen_soc_buffer: f64,
pub udds: PHEVCycleCalc,
pub hwy: PHEVCycleCalc,
}Expand description
Label fuel economy values for a PHEV vehicle
Fields
regen_soc_buffer: f64udds: PHEVCycleCalchwy: PHEVCycleCalcTrait Implementations
sourceimpl ApproxEq for LabelFePHEV
impl ApproxEq for LabelFePHEV
sourceimpl Clone for LabelFePHEV
impl Clone for LabelFePHEV
sourcefn clone(&self) -> LabelFePHEV
fn clone(&self) -> LabelFePHEV
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for LabelFePHEV
impl Debug for LabelFePHEV
sourceimpl Default for LabelFePHEV
impl Default for LabelFePHEV
sourcefn default() -> LabelFePHEV
fn default() -> LabelFePHEV
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for LabelFePHEV
impl<'de> Deserialize<'de> for LabelFePHEV
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq for LabelFePHEV
impl PartialEq for LabelFePHEV
sourcefn eq(&self, other: &LabelFePHEV) -> bool
fn eq(&self, other: &LabelFePHEV) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl SerdeAPI for LabelFePHEV
impl SerdeAPI for LabelFePHEV
const ACCEPTED_BYTE_FORMATS: &'static [&'static str] = _
const ACCEPTED_STR_FORMATS: &'static [&'static str] = _
const CACHE_FOLDER: &'static str = _
sourcefn from_resource<P: AsRef<Path>>(filepath: P) -> Result<Self>
fn from_resource<P: AsRef<Path>>(filepath: P) -> Result<Self>
Read (deserialize) an object from a resource file packaged with the
fastsim-core crate Read moresourcefn to_file<P: AsRef<Path>>(&self, filepath: P) -> Result<()>
fn to_file<P: AsRef<Path>>(&self, filepath: P) -> Result<()>
Write (serialize) an object to a file.
Supported file extensions are listed in
ACCEPTED_BYTE_FORMATS.
Creates a new file if it does not already exist, otherwise truncates the existing file. Read morefn to_writer<W: Write>(&self, wtr: W, format: &str) -> Result<()>
sourcefn from_file<P: AsRef<Path>>(filepath: P) -> Result<Self>
fn from_file<P: AsRef<Path>>(filepath: P) -> Result<Self>
Read (deserialize) an object from a file.
Supported file extensions are listed in
ACCEPTED_BYTE_FORMATS. Read moresourcefn to_str(&self, format: &str) -> Result<String>
fn to_str(&self, format: &str) -> Result<String>
Write (serialize) an object into a string Read more
sourcefn from_str<S: AsRef<str>>(contents: S, format: &str) -> Result<Self>
fn from_str<S: AsRef<str>>(contents: S, format: &str) -> Result<Self>
Read (deserialize) an object from a string Read more
sourcefn from_reader<R: Read>(rdr: R, format: &str) -> Result<Self>
fn from_reader<R: Read>(rdr: R, format: &str) -> Result<Self>
Deserialize an object from anything that implements
std::io::Read Read moresourcefn from_json<S: AsRef<str>>(json_str: S) -> Result<Self>
fn from_json<S: AsRef<str>>(json_str: S) -> Result<Self>
Read (deserialize) an object to a JSON string Read more
sourcefn from_yaml<S: AsRef<str>>(yaml_str: S) -> Result<Self>
fn from_yaml<S: AsRef<str>>(yaml_str: S) -> Result<Self>
Read (deserialize) an object from a YAML string Read more
sourcefn from_bincode(encoded: &[u8]) -> Result<Self>
fn from_bincode(encoded: &[u8]) -> Result<Self>
Read (deserialize) an object from bincode-encoded bytes Read more
sourcefn from_url<S: AsRef<str>>(url: S) -> Result<Self>
fn from_url<S: AsRef<str>>(url: S) -> Result<Self>
Instantiates an object from a url. Accepts yaml and json file types Read more
sourcefn to_cache<P: AsRef<Path>>(&self, file_path: P) -> Result<()>
fn to_cache<P: AsRef<Path>>(&self, file_path: P) -> Result<()>
Takes an instantiated Rust object and saves it in the FASTSim data directory in
a rust_objects folder.
WARNING: If there is a file already in the data subdirectory with the same name, it will be replaced by the new file. Read more
WARNING: If there is a file already in the data subdirectory with the same name, it will be replaced by the new file. Read more
sourcefn from_cache<P: AsRef<Path>>(file_path: P) -> Result<Self>
fn from_cache<P: AsRef<Path>>(file_path: P) -> Result<Self>
Instantiates a Rust object from the subdirectory within the FASTSim data
directory corresponding to the Rust Object (“vehices” for a RustVehice,
“cycles” for a RustCycle, and the root folder of the data directory for
all other objects). Read more
sourceimpl Serialize for LabelFePHEV
impl Serialize for LabelFePHEV
impl StructuralPartialEq for LabelFePHEV