Struct fastsim_core::simdrivelabel::LabelFePHEV
source · pub struct LabelFePHEV {
pub regen_soc_buffer: f64,
pub udds: PHEVCycleCalc,
pub hwy: PHEVCycleCalc,
}Expand description
Label fuel economy values for a PHEV vehicle
Fields
regen_soc_buffer: f64udds: PHEVCycleCalchwy: PHEVCycleCalcTrait Implementations
sourceimpl ApproxEq<LabelFePHEV> for LabelFePHEV
impl ApproxEq<LabelFePHEV> for LabelFePHEV
sourceimpl Clone for LabelFePHEV
impl Clone for LabelFePHEV
sourcefn clone(&self) -> LabelFePHEV
fn clone(&self) -> LabelFePHEV
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for LabelFePHEV
impl Debug for LabelFePHEV
sourceimpl Default for LabelFePHEV
impl Default for LabelFePHEV
sourcefn default() -> LabelFePHEV
fn default() -> LabelFePHEV
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for LabelFePHEV
impl<'de> Deserialize<'de> for LabelFePHEV
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<LabelFePHEV> for LabelFePHEV
impl PartialEq<LabelFePHEV> for LabelFePHEV
sourcefn eq(&self, other: &LabelFePHEV) -> bool
fn eq(&self, other: &LabelFePHEV) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl SerdeAPI for LabelFePHEV
impl SerdeAPI for LabelFePHEV
sourcefn to_file(&self, filename: &str) -> Result<(), Error>
fn to_file(&self, filename: &str) -> Result<(), Error>
Save current data structure to file. Method adaptively calls serialization methods
dependent on the suffix of the file given as str. Read more
sourcefn from_file(filename: &str) -> Result<Self, Error>where
for<'de> Self: Sized + Deserialize<'de>,
fn from_file(filename: &str) -> Result<Self, Error>where for<'de> Self: Sized + Deserialize<'de>,
Read from file and return instantiated struct. Method adaptively calls deserialization
methods dependent on the suffix of the file name given as str.
Function returns a dynamic Error Result if it fails. Read more
sourcefn to_bincode(&self) -> Vec<u8>
fn to_bincode(&self) -> Vec<u8>
bincode serialization method.
sourceimpl Serialize for LabelFePHEV
impl Serialize for LabelFePHEV
impl StructuralPartialEq for LabelFePHEV