pub struct PHEVCycleCalc {Show 42 fields
pub cd_ess_kwh: f64,
pub cd_ess_kwh_per_mi: f64,
pub cd_fs_gal: f64,
pub cd_fs_kwh: f64,
pub cd_mpg: f64,
pub cd_cycs: f64,
pub cd_miles: f64,
pub cd_lab_mpg: f64,
pub cd_adj_mpg: f64,
pub cd_frac_in_trans: f64,
pub trans_init_soc: f64,
pub trans_ess_kwh: f64,
pub trans_ess_kwh_per_mi: f64,
pub trans_fs_gal: f64,
pub trans_fs_kwh: f64,
pub cs_ess_kwh: f64,
pub cs_ess_kwh_per_mi: f64,
pub cs_fs_gal: f64,
pub cs_fs_kwh: f64,
pub cs_mpg: f64,
pub lab_mpgge: f64,
pub lab_kwh_per_mi: f64,
pub lab_uf: f64,
pub lab_uf_gpm: Array1<f64>,
pub lab_iter_uf: Array1<f64>,
pub lab_iter_uf_kwh_per_mi: Array1<f64>,
pub lab_iter_kwh_per_mi: Array1<f64>,
pub adj_iter_mpgge: Array1<f64>,
pub adj_iter_kwh_per_mi: Array1<f64>,
pub adj_iter_cd_miles: Array1<f64>,
pub adj_iter_uf: Array1<f64>,
pub adj_iter_uf_gpm: Vec<f64>,
pub adj_iter_uf_kwh_per_mi: Array1<f64>,
pub adj_cd_miles: f64,
pub adj_cd_mpgge: f64,
pub adj_cs_mpgge: f64,
pub adj_uf: f64,
pub adj_mpgge: f64,
pub adj_kwh_per_mi: f64,
pub adj_ess_kwh_per_mi: f64,
pub delta_soc: f64,
pub total_cd_miles: f64,
}Expand description
Label fuel economy calculations for a specific cycle of a PHEV vehicle
Fields
cd_ess_kwh: f64Charge depletion battery kW-hr
cd_ess_kwh_per_mi: f64cd_fs_gal: f64Charge depletion fuel gallons
cd_fs_kwh: f64cd_mpg: f64cd_cycs: f64Number of cycles in charge depletion mode, up to transition
cd_miles: f64cd_lab_mpg: f64cd_adj_mpg: f64cd_frac_in_trans: f64Fraction of transition cycles spent in charge depletion
trans_init_soc: f64SOC change during 1 cycle
trans_ess_kwh: f64charge depletion battery kW-hr
trans_ess_kwh_per_mi: f64trans_fs_gal: f64trans_fs_kwh: f64cs_ess_kwh: f64charge sustaining battery kW-hr
cs_ess_kwh_per_mi: f64cs_fs_gal: f64charge sustaining fuel gallons
cs_fs_kwh: f64cs_mpg: f64lab_mpgge: f64lab_kwh_per_mi: f64lab_uf: f64lab_uf_gpm: Array1<f64>lab_iter_uf: Array1<f64>lab_iter_uf_kwh_per_mi: Array1<f64>lab_iter_kwh_per_mi: Array1<f64>adj_iter_mpgge: Array1<f64>adj_iter_kwh_per_mi: Array1<f64>adj_iter_cd_miles: Array1<f64>adj_iter_uf: Array1<f64>adj_iter_uf_gpm: Vec<f64>adj_iter_uf_kwh_per_mi: Array1<f64>adj_cd_miles: f64adj_cd_mpgge: f64adj_cs_mpgge: f64adj_uf: f64adj_mpgge: f64adj_kwh_per_mi: f64adj_ess_kwh_per_mi: f64delta_soc: f64total_cd_miles: f64Total number of miles in charge depletion mode, assuming constant kWh_per_mi