pub struct ThermalState {
Show 32 fields pub fc_te_deg_c: f64, pub fc_eta_temp_coeff: f64, pub fc_qdot_per_net_heat: f64, pub fc_qdot_kw: f64, pub fc_qdot_to_amb_kw: f64, pub fc_qdot_to_htr_kw: f64, pub fc_htc_to_amb: f64, pub fc_lambda: f64, pub fc_te_adiabatic_deg_c: f64, pub cab_te_deg_c: f64, pub cab_prev_te_deg_c: f64, pub cab_qdot_solar_kw: f64, pub cab_qdot_to_amb_kw: f64, pub cab_qdot_from_hvac_kw: f64, pub cab_hvac_pwr_aux_kw: f64, pub exh_mdot: f64, pub exh_hdot_kw: f64, pub exhport_exh_te_in_deg_c: f64, pub exhport_qdot_to_amb: f64, pub exhport_te_deg_c: f64, pub exhport_qdot_from_exh: f64, pub exhport_qdot_net: f64, pub cat_qdot: f64, pub cat_htc_to_amb: f64, pub cat_qdot_to_amb: f64, pub cat_te_deg_c: f64, pub cat_exh_te_in_deg_c: f64, pub cat_re_ext: f64, pub cat_qdot_from_exh: f64, pub cat_qdot_net: f64, pub amb_te_deg_c: f64, pub orphaned: bool,
}
Struct containing thermal state variables for all thermal components

Fields

fc_te_deg_c: f64

fuel converter (engine) temperature [°C]

fc_eta_temp_coeff: f64

fuel converter temperature efficiency correction

fc_qdot_per_net_heat: f64

fuel converter heat generation per total heat release minus shaft power

fc_qdot_kw: f64

fuel converter heat generation [kW]

fc_qdot_to_amb_kw: f64

fuel converter convection to ambient [kW]

fc_qdot_to_htr_kw: f64

fuel converter heat loss to heater core [kW]

fc_htc_to_amb: f64

heat transfer coeff [W / (m ** 2 * K)] to amb after arbitration

fc_lambda: f64

lambda (air/fuel ratio normalized w.r.t. stoich air/fuel ratio) – 1 is reasonable default

fc_te_adiabatic_deg_c: f64

lambda-dependent adiabatic flame temperature

cab_te_deg_c: f64

cabin temperature [°C]

cab_prev_te_deg_c: f64

previous cabin temperature [°C]

cab_qdot_solar_kw: f64

cabin solar load [kw]

cab_qdot_to_amb_kw: f64

cabin convection to ambient [kw]

cab_qdot_from_hvac_kw: f64

heat transfer to cabin from hvac system

cab_hvac_pwr_aux_kw: f64

aux load from hvac

exh_mdot: f64

exhaust mass flow rate [kg/s]

exh_hdot_kw: f64

exhaust enthalpy flow rate [kw]

exhport_exh_te_in_deg_c: f64

exhaust port (exhport) variables exhaust temperature at exhaust port inlet

exhport_qdot_to_amb: f64

heat transfer from exhport to amb [kw]

exhport_te_deg_c: f64

catalyst temperature [°C]

exhport_qdot_from_exh: f64

convection from exhaust to exhport [W] positive means exhport is receiving heat

exhport_qdot_net: f64

net heat generation in cat [W]

cat_qdot: f64

catalyst heat generation [W]

cat_htc_to_amb: f64

catalytic converter convection coefficient to ambient [W / (m ** 2 * K)]

cat_qdot_to_amb: f64

heat transfer from catalyst to ambient [W]

cat_te_deg_c: f64

catalyst temperature [°C]

cat_exh_te_in_deg_c: f64

exhaust temperature at cat inlet

cat_re_ext: f64

catalyst external reynolds number

cat_qdot_from_exh: f64

convection from exhaust to cat [W] positive means cat is receiving heat

cat_qdot_net: f64

net heat generation in cat [W]

amb_te_deg_c: f64

ambient temperature

orphaned: bool

Implementations

source

impl ThermalState

source

pub fn new( amb_te_deg_c: Option<f64>, fc_te_deg_c_init: Option<f64>, cab_te_deg_c_init: Option<f64>, exhport_te_deg_c_init: Option<f64>, cat_te_deg_c_init: Option<f64> ) -> Self