Struct fastsim_core::thermal::ThermalState
source · pub struct ThermalState {Show 32 fields
pub fc_te_deg_c: f64,
pub fc_eta_temp_coeff: f64,
pub fc_qdot_per_net_heat: f64,
pub fc_qdot_kw: f64,
pub fc_qdot_to_amb_kw: f64,
pub fc_qdot_to_htr_kw: f64,
pub fc_htc_to_amb: f64,
pub fc_lambda: f64,
pub fc_te_adiabatic_deg_c: f64,
pub cab_te_deg_c: f64,
pub cab_prev_te_deg_c: f64,
pub cab_qdot_solar_kw: f64,
pub cab_qdot_to_amb_kw: f64,
pub cab_qdot_from_hvac_kw: f64,
pub cab_hvac_pwr_aux_kw: f64,
pub exh_mdot: f64,
pub exh_hdot_kw: f64,
pub exhport_exh_te_in_deg_c: f64,
pub exhport_qdot_to_amb: f64,
pub exhport_te_deg_c: f64,
pub exhport_qdot_from_exh: f64,
pub exhport_qdot_net: f64,
pub cat_qdot: f64,
pub cat_htc_to_amb: f64,
pub cat_qdot_to_amb: f64,
pub cat_te_deg_c: f64,
pub cat_exh_te_in_deg_c: f64,
pub cat_re_ext: f64,
pub cat_qdot_from_exh: f64,
pub cat_qdot_net: f64,
pub amb_te_deg_c: f64,
pub orphaned: bool,
}Expand description
Struct containing thermal state variables for all thermal components
Fields
fc_te_deg_c: f64fuel converter (engine) temperature [°C]
fc_eta_temp_coeff: f64fuel converter temperature efficiency correction
fc_qdot_per_net_heat: f64fuel converter heat generation per total heat release minus shaft power
fc_qdot_kw: f64fuel converter heat generation [kW]
fc_qdot_to_amb_kw: f64fuel converter convection to ambient [kW]
fc_qdot_to_htr_kw: f64fuel converter heat loss to heater core [kW]
fc_htc_to_amb: f64heat transfer coeff [W / (m ** 2 * K)] to amb after arbitration
fc_lambda: f64lambda (air/fuel ratio normalized w.r.t. stoich air/fuel ratio) – 1 is reasonable default
fc_te_adiabatic_deg_c: f64lambda-dependent adiabatic flame temperature
cab_te_deg_c: f64cabin temperature [°C]
cab_prev_te_deg_c: f64previous cabin temperature [°C]
cab_qdot_solar_kw: f64cabin solar load [kw]
cab_qdot_to_amb_kw: f64cabin convection to ambient [kw]
cab_qdot_from_hvac_kw: f64heat transfer to cabin from hvac system
cab_hvac_pwr_aux_kw: f64aux load from hvac
exh_mdot: f64exhaust mass flow rate [kg/s]
exh_hdot_kw: f64exhaust enthalpy flow rate [kw]
exhport_exh_te_in_deg_c: f64exhaust port (exhport) variables exhaust temperature at exhaust port inlet
exhport_qdot_to_amb: f64heat transfer from exhport to amb [kw]
exhport_te_deg_c: f64catalyst temperature [°C]
exhport_qdot_from_exh: f64convection from exhaust to exhport [W] positive means exhport is receiving heat
exhport_qdot_net: f64net heat generation in cat [W]
cat_qdot: f64catalyst heat generation [W]
cat_htc_to_amb: f64catalytic converter convection coefficient to ambient [W / (m ** 2 * K)]
cat_qdot_to_amb: f64heat transfer from catalyst to ambient [W]
cat_te_deg_c: f64catalyst temperature [°C]
cat_exh_te_in_deg_c: f64exhaust temperature at cat inlet
cat_re_ext: f64catalyst external reynolds number
cat_qdot_from_exh: f64convection from exhaust to cat [W] positive means cat is receiving heat
cat_qdot_net: f64net heat generation in cat [W]
amb_te_deg_c: f64ambient temperature
orphaned: boolImplementations