Trait HistoryMethods

pub trait HistoryMethods: SaveState {
    // Required methods
    fn set_save_interval(&mut self, save_interval: Option<usize>) -> Result<()>;
    fn save_interval(&self) -> Result<Option<usize>>;
    fn clear(&mut self);
}
Provides methods for getting and setting the save interval

Required Methods

fn set_save_interval(&mut self, save_interval: Option<usize>) -> Result<()>

Recursively sets save interval

Arguments
  • save_interval: time step interval at which to save self.state to self.history
fn save_interval(&self) -> Result<Option<usize>>

Returns save interval for self but does not guarantee recursive consistency in nested objects

fn clear(&mut self)

Remove all history

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors