Module containing miscellaneous utility functions.
Constants
- Error message for when user attempts to set value in a nested struct.
Functions
- Returns a new array with a constant added starting at xs[i] to the end. Values prior to xs[i] are unchanged.
- return max of arr
- return min of arr
- Deletes FASTSim data directory, clearing its contents. If subpath is provided, will only delete the subdirectory pointed to by the subpath, rather than deleting the whole data directory. If the subpath is an empty string, deletes the entire FASTSim directory. USE WITH CAUTION, as this function deletes ALL objects stored in the FASTSim data directory or provided subdirectory.
- Creates/gets an OS-specific data directory and returns the path.
- Assumes the parent directory exists. Assumes file doesn’t exist (i.e., newly created) or that it will be truncated if it does.
- Return first index of
arrequal tocut - Return first index of
arrgreater thancut - Generate all permutations of indices for a given N-dimensional array shape
- interpolation algorithm from http://www.cplusplus.com/forum/general/216928/ Arguments: x : value at which to interpolate
- interpolation algorithm from http://www.cplusplus.com/forum/general/216928/ Arguments: x : value at which to interpolate
- return max of 2 f64
- return min of 2 f64
- Multilinear interpolation function, accepting any dimensionality N.
- return true if the array is all zeros
- return cumsum of arr
- return the unique values of the array
- Returns the path to the OS-specific data directory, if it exists.
- Calculate tire radius (in meters) from an ISO metric tire code
- takes an object from a url and saves it in the FASTSim data directory in a rust_objects folder WARNING: if there is a file already in the data subdirectory with the same name, it will be replaced by the new file to save to a folder other than rust_objects, define constant CACHE_FOLDER to be the desired folder name