Module fastsim_core::utils
source · Expand description
Module containing miscellaneous utility functions.
Constants
- Error message for when user attempts to set value in a nested struct.
Functions
- Returns a new array with a constant added starting at xs[i] to the end. Values prior to xs[i] are unchanged.
- return max of arr
- return min of arr
- Return first index of
arrequal tocut - Return first index of
arrgreater thancut - interpolation algorithm from http://www.cplusplus.com/forum/general/216928/ Arguments: x : value at which to interpolate
- interpolation algorithm from http://www.cplusplus.com/forum/general/216928/ Arguments: x : value at which to interpolate
- return max of 2 f64
- return min of 2 f64
- return true if the array is all zeros
- return cumsum of arr
- return max of arr
- return min of arr
- return the unique values of the array