pub struct TrackedState<T>(/* private fields */);Expand description
Struct for storing state variable and ensuring one mutation per initialization or reset – i.e. one mutation per time step
Implementations
Sourceimpl<T> TrackedState<T>
Provides methods to guarantee that states are updated once and only once per time step
impl<T> TrackedState<T>
Provides methods to guarantee that states are updated once and only once per time step
pub fn new(value: T) -> Self
Sourcepub fn mark_stale(&mut self)
pub fn mark_stale(&mut self)
Reset the tracked state to [State::Stale] for the next update after verifying that is has been updated
Sourcepub fn update<F: Fn() -> String>(&mut self, value: T, loc: F) -> Result<()>
pub fn update<F: Fn() -> String>(&mut self, value: T, loc: F) -> Result<()>
Update the value of the tracked state after verifying that it has not already been updated
Arguments
value: new valueloc: closure that returns file and line number where called
Sourcepub fn update_unchecked<F: Fn() -> String>(
&mut self,
value: T,
_loc: F,
) -> Result<()>
pub fn update_unchecked<F: Fn() -> String>( &mut self, value: T, _loc: F, ) -> Result<()>
Update the value of the tracked state without verifying that it has not already been updated – to be used sparingly!
Arguments
value: new valueloc: closure that returns file and line number where called