#[non_exhaustive]pub struct DfcoControls {
pub dfco_enabled: bool,
pub minimum_dfco_speed: Velocity,
pub minimum_dfco_deceleration: Acceleration,
pub stopped_speed_threshold: Velocity,
pub save_interval: Option<usize>,
pub state: DfcoState,
pub history: DfcoStateHistoryVec,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dfco_enabled: boolIf true DFCO is enabled, else it will never run.
minimum_dfco_speed: VelocityThe minimum speed at or above which which DFCO can activate.
minimum_dfco_deceleration: AccelerationThe minimum vehicle acceleration required for DFCO to be able to activate.
stopped_speed_threshold: VelocitySpeed threshold at or below which DFCO is considered unavailable due to near-stop operation.
save_interval: Option<usize>Time step interval between saves. 1 is a good option. If None, no saving occurs.
state: DfcoStatecurrent state of control variables
history: DfcoStateHistoryVechistory of current state
Implementations
Sourceimpl DfcoControls
impl DfcoControls
Sourcepub fn is_dfco_disabled_due_to_veh_dynamics(
prev_speed: Velocity,
speed: Velocity,
dt: Time,
dfco_allowed: bool,
minimum_dfco_speed: Velocity,
minimum_dfco_deceleration: Acceleration,
stopped_speed_threshold: Velocity,
) -> bool
pub fn is_dfco_disabled_due_to_veh_dynamics( prev_speed: Velocity, speed: Velocity, dt: Time, dfco_allowed: bool, minimum_dfco_speed: Velocity, minimum_dfco_deceleration: Acceleration, stopped_speed_threshold: Velocity, ) -> bool
Determine if decel fuel cut-off (DFCO) is disabled based on vehicle dynamics considerations (i.e., speed, acceleration). Note: considerations related to whether the engine is too cold and such would be handled elsewhere.