pub struct RustVehicle {
Show 126 fields pub props: RustPhysicalProperties, pub scenario_name: String, pub selection: u32, pub veh_year: u32, pub veh_pt_type: String, pub drag_coef: f64, pub frontal_area_m2: f64, pub glider_kg: f64, pub veh_cg_m: f64, pub drive_axle_weight_frac: f64, pub wheel_base_m: f64, pub cargo_kg: f64, pub veh_override_kg: Option<f64>, pub comp_mass_multiplier: f64, pub fs_max_kw: f64, pub fs_secs_to_peak_pwr: f64, pub fs_kwh: f64, pub fs_kwh_per_kg: f64, pub fc_max_kw: f64, pub fc_pwr_out_perc: Array1<f64>, pub fc_eff_map: Array1<f64>, pub fc_eff_type: String, pub fc_sec_to_peak_pwr: f64, pub fc_base_kg: f64, pub fc_kw_per_kg: f64, pub min_fc_time_on: f64, pub idle_fc_kw: f64, pub mc_max_kw: f64, pub mc_pwr_out_perc: Array1<f64>, pub mc_eff_map: Array1<f64>, pub mc_sec_to_peak_pwr: f64, pub mc_pe_kg_per_kw: f64, pub mc_pe_base_kg: f64, pub ess_max_kw: f64, pub ess_max_kwh: f64, pub ess_kg_per_kwh: f64, pub ess_base_kg: f64, pub ess_round_trip_eff: f64, pub ess_life_coef_a: f64, pub ess_life_coef_b: f64, pub min_soc: f64, pub max_soc: f64, pub ess_dischg_to_fc_max_eff_perc: f64, pub ess_chg_to_fc_max_eff_perc: f64, pub wheel_inertia_kg_m2: f64, pub num_wheels: f64, pub wheel_rr_coef: f64, pub wheel_radius_m: f64, pub wheel_coef_of_fric: f64, pub max_accel_buffer_mph: f64, pub max_accel_buffer_perc_of_useable_soc: f64, pub perc_high_acc_buf: f64, pub mph_fc_on: f64, pub kw_demand_fc_on: f64, pub max_regen: f64, pub stop_start: bool, pub force_aux_on_fc: bool, pub alt_eff: f64, pub chg_eff: f64, pub aux_kw: f64, pub trans_kg: f64, pub trans_eff: f64, pub ess_to_fuel_ok_error: f64, pub fc_peak_eff_override: Option<f64>, pub mc_peak_eff_override: Option<f64>, pub drag_coef_doc: Option<String>, pub frontal_area_m2_doc: Option<String>, pub glider_kg_doc: Option<String>, pub veh_cg_m_doc: Option<String>, pub drive_axle_weight_frac_doc: Option<String>, pub wheel_base_m_doc: Option<String>, pub cargo_kg_doc: Option<String>, pub veh_override_kg_doc: Option<String>, pub comp_mass_multiplier_doc: Option<String>, pub fs_max_kw_doc: Option<String>, pub fs_secs_to_peak_pwr_doc: Option<String>, pub fs_kwh_doc: Option<String>, pub fs_kwh_per_kg_doc: Option<String>, pub fc_max_kw_doc: Option<String>, pub fc_pwr_out_perc_doc: Option<String>, pub fc_eff_map_doc: Option<String>, pub fc_eff_type_doc: Option<String>, pub fc_sec_to_peak_pwr_doc: Option<String>, pub fc_base_kg_doc: Option<String>, pub fc_kw_per_kg_doc: Option<String>, pub min_fc_time_on_doc: Option<String>, pub idle_fc_kw_doc: Option<String>, pub mc_max_kw_doc: Option<String>, pub mc_pwr_out_perc_doc: Option<String>, pub mc_eff_map_doc: Option<String>, pub mc_sec_to_peak_pwr_doc: Option<String>, pub mc_pe_kg_per_kw_doc: Option<String>, pub mc_pe_base_kg_doc: Option<String>, pub ess_max_kw_doc: Option<String>, pub ess_max_kwh_doc: Option<String>, pub ess_kg_per_kwh_doc: Option<String>, pub ess_base_kg_doc: Option<String>, pub ess_round_trip_eff_doc: Option<String>, pub ess_life_coef_a_doc: Option<String>, pub ess_life_coef_b_doc: Option<String>, pub min_soc_doc: Option<String>, pub max_soc_doc: Option<String>, pub ess_dischg_to_fc_max_eff_perc_doc: Option<String>, pub ess_chg_to_fc_max_eff_perc_doc: Option<String>, pub wheel_inertia_kg_m2_doc: Option<String>, pub num_wheels_doc: Option<String>, pub wheel_rr_coef_doc: Option<String>, pub wheel_radius_m_doc: Option<String>, pub wheel_coef_of_fric_doc: Option<String>, pub max_accel_buffer_mph_doc: Option<String>, pub max_accel_buffer_perc_of_useable_soc_doc: Option<String>, pub perc_high_acc_buf_doc: Option<String>, pub mph_fc_on_doc: Option<String>, pub kw_demand_fc_on_doc: Option<String>, pub max_regen_doc: Option<String>, pub stop_start_doc: Option<String>, pub force_aux_on_fc_doc: Option<String>, pub alt_eff_doc: Option<String>, pub chg_eff_doc: Option<String>, pub aux_kw_doc: Option<String>, pub trans_kg_doc: Option<String>, pub trans_eff_doc: Option<String>, pub ess_to_fuel_ok_error_doc: Option<String>, pub fc_peak_eff_override_doc: Option<String>, pub mc_peak_eff_override_doc: Option<String>, pub doc: Option<String>, /* private fields */
}
Struct containing vehicle attributes

Python Examples

import fastsim

## Load drive cycle by name
cyc_py = fastsim.cycle.Cycle.from_file("udds")
cyc_rust = cyc_py.to_rust()

Fields

props: RustPhysicalProperties

Physical properties, see RustPhysicalProperties

scenario_name: String

Vehicle name

selection: u32

Vehicle database ID

veh_year: u32

Vehicle year

veh_pt_type: String

Vehicle powertrain type, one of [CONV, HEV, PHEV, BEV]

drag_coef: f64

Aerodynamic drag coefficient

frontal_area_m2: f64

Frontal area, $m^2$

glider_kg: f64

Vehicle mass excluding cargo, passengers, and powertrain components, $kg$

veh_cg_m: f64

Vehicle center of mass height, $m$ NOTE: positive for FWD, negative for RWD, AWD, 4WD

drive_axle_weight_frac: f64

Fraction of weight on the drive axle while stopped

wheel_base_m: f64

Wheelbase, $m$

cargo_kg: f64

Cargo mass including passengers, $kg$

veh_override_kg: Option<f64>

Total vehicle mass, overrides mass calculation, $kg$

comp_mass_multiplier: f64

Component mass multiplier for vehicle mass calculation

fs_max_kw: f64

Fuel storage max power output, $kW$

fs_secs_to_peak_pwr: f64

Fuel storage time to peak power, $s$

fs_kwh: f64

Fuel storage energy capacity, $kWh$

fs_kwh_per_kg: f64

Fuel specific energy, $\frac{kWh}{kg}$

fc_max_kw: f64

Fuel converter peak continuous power, $kW$

fc_pwr_out_perc: Array1<f64>

Fuel converter output power percentage map, x-values of fc_eff_map

fc_eff_map: Array1<f64>

Fuel converter efficiency map

fc_eff_type: String

Fuel converter efficiency type, one of [SI, ATKINSON, DIESEL, H2FC, HD_DIESEL] Used for calculating fc_eff_map, and other calculations if H2FC

fc_sec_to_peak_pwr: f64

Fuel converter time to peak power, $s$

fc_base_kg: f64

Fuel converter base mass, $kg$

fc_kw_per_kg: f64

Fuel converter specific power (power-to-weight ratio), $\frac{kW}{kg}$

min_fc_time_on: f64

Minimum time fuel converter must be on before shutoff (for HEV, PHEV)

idle_fc_kw: f64

Fuel converter idle power, $kW$

mc_max_kw: f64

Peak continuous electric motor power, $kW$

mc_pwr_out_perc: Array1<f64>

Electric motor output power percentage map, x-values of mc_eff_map

mc_eff_map: Array1<f64>

Electric motor efficiency map

mc_sec_to_peak_pwr: f64

Electric motor time to peak power, $s$

mc_pe_kg_per_kw: f64

Motor power electronics mass per power output, $\frac{kg}{kW}$

mc_pe_base_kg: f64

Motor power electronics base mass, $kg$

ess_max_kw: f64

Traction battery maximum power output, $kW$

ess_max_kwh: f64

Traction battery energy capacity, $kWh$

ess_kg_per_kwh: f64

Traction battery mass per energy, $\frac{kg}{kWh}$

ess_base_kg: f64

Traction battery base mass, $kg$

ess_round_trip_eff: f64

Traction battery round-trip efficiency

ess_life_coef_a: f64

Traction battery cycle life coefficient A, see reference

ess_life_coef_b: f64

Traction battery cycle life coefficient B, see reference

min_soc: f64

Traction battery minimum state of charge

max_soc: f64

Traction battery maximum state of charge

ess_dischg_to_fc_max_eff_perc: f64

ESS discharge effort toward max FC efficiency

ess_chg_to_fc_max_eff_perc: f64

ESS charge effort toward max FC efficiency

wheel_inertia_kg_m2: f64

Mass moment of inertia per wheel, $kg \cdot m^2$

num_wheels: f64

Number of wheels

wheel_rr_coef: f64

Rolling resistance coefficient

wheel_radius_m: f64

Wheel radius, $m$

wheel_coef_of_fric: f64

Wheel coefficient of friction

max_accel_buffer_mph: f64

Speed where the battery reserved for accelerating is zero

max_accel_buffer_perc_of_useable_soc: f64

Percent of usable battery energy reserved to help accelerate

perc_high_acc_buf: f64

Percent SOC buffer for high accessory loads during cycles with long idle time

mph_fc_on: f64

Speed at which the fuel converter must turn on, $mph$

kw_demand_fc_on: f64

Power demand above which to require fuel converter on, $kW$

max_regen: f64

Maximum brake regeneration efficiency

stop_start: bool

Stop/start micro-HEV flag

force_aux_on_fc: bool

Force auxiliary power load to come from fuel converter

alt_eff: f64

Alternator efficiency

chg_eff: f64

Charger efficiency

aux_kw: f64

Auxiliary load power, $kW$

trans_kg: f64

Transmission mass, $kg$

trans_eff: f64

Transmission efficiency

ess_to_fuel_ok_error: f64

Maximum acceptable ratio of change in ESS energy to expended fuel energy (used in hybrid SOC balancing), $\frac{\Delta E_{ESS}}{\Delta E_{fuel}}$

fc_peak_eff_override: Option<f64>

Fuel converter efficiency peak override, scales entire curve

mc_peak_eff_override: Option<f64>

Motor efficiency peak override, scales entire curve

drag_coef_doc: Option<String>

drag_coef documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

frontal_area_m2_doc: Option<String>

frontal_area_m2 documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

glider_kg_doc: Option<String>

glider_kg documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

veh_cg_m_doc: Option<String>

veh_cg_m documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

drive_axle_weight_frac_doc: Option<String>

drive_axle_weight_frac documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

wheel_base_m_doc: Option<String>

wheel_base_m documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

cargo_kg_doc: Option<String>

cargo_kg documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

veh_override_kg_doc: Option<String>

veh_override_kg documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

comp_mass_multiplier_doc: Option<String>

comp_mass_multiplier documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fs_max_kw_doc: Option<String>

fs_max_kw documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fs_secs_to_peak_pwr_doc: Option<String>

fs_secs_to_peak_pwr documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fs_kwh_doc: Option<String>

fs_kwh documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fs_kwh_per_kg_doc: Option<String>

fs_kwh_per_kg documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fc_max_kw_doc: Option<String>

fc_max_kw documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fc_pwr_out_perc_doc: Option<String>

fc_pwr_out_perc documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fc_eff_map_doc: Option<String>

fc_eff_map documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fc_eff_type_doc: Option<String>

fc_eff_type documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fc_sec_to_peak_pwr_doc: Option<String>

fc_sec_to_peak_pwr documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fc_base_kg_doc: Option<String>

fc_base_kg documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fc_kw_per_kg_doc: Option<String>

fc_kw_per_kg documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

min_fc_time_on_doc: Option<String>

min_fc_time_on documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

idle_fc_kw_doc: Option<String>

idle_fc_kw documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

mc_max_kw_doc: Option<String>

mc_max_kw documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

mc_pwr_out_perc_doc: Option<String>

mc_pwr_out_perc documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

mc_eff_map_doc: Option<String>

mc_eff_map documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

mc_sec_to_peak_pwr_doc: Option<String>

mc_sec_to_peak_pwr documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

mc_pe_kg_per_kw_doc: Option<String>

mc_pe_kg_per_kw documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

mc_pe_base_kg_doc: Option<String>

mc_pe_base_kg documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

ess_max_kw_doc: Option<String>

ess_max_kw documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

ess_max_kwh_doc: Option<String>

ess_max_kwh documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

ess_kg_per_kwh_doc: Option<String>

ess_kg_per_kwh documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

ess_base_kg_doc: Option<String>

ess_base_kg documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

ess_round_trip_eff_doc: Option<String>

ess_round_trip_eff documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

ess_life_coef_a_doc: Option<String>

ess_life_coef_a documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

ess_life_coef_b_doc: Option<String>

ess_life_coef_b documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

min_soc_doc: Option<String>

min_soc documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

max_soc_doc: Option<String>

max_soc documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

ess_dischg_to_fc_max_eff_perc_doc: Option<String>

ess_dischg_to_fc_max_eff_perc documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

ess_chg_to_fc_max_eff_perc_doc: Option<String>

ess_chg_to_fc_max_eff_perc documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

wheel_inertia_kg_m2_doc: Option<String>

wheel_inertia_kg_m2 documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

num_wheels_doc: Option<String>

num_wheels documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

wheel_rr_coef_doc: Option<String>

wheel_rr_coef documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

wheel_radius_m_doc: Option<String>

wheel_radius_m documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

wheel_coef_of_fric_doc: Option<String>

wheel_coef_of_fric documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

max_accel_buffer_mph_doc: Option<String>

max_accel_buffer_mph documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

max_accel_buffer_perc_of_useable_soc_doc: Option<String>

max_accel_buffer_perc_of_useable_soc documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

perc_high_acc_buf_doc: Option<String>

perc_high_acc_buf documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

mph_fc_on_doc: Option<String>

mph_fc_on documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

kw_demand_fc_on_doc: Option<String>

kw_demand_fc_on documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

max_regen_doc: Option<String>

max_regen documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

stop_start_doc: Option<String>

stop_start documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

force_aux_on_fc_doc: Option<String>

force_aux_on_fc documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

alt_eff_doc: Option<String>

alt_eff documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

chg_eff_doc: Option<String>

chg_eff documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

aux_kw_doc: Option<String>

aux_kw documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

trans_kg_doc: Option<String>

trans_kg documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

trans_eff_doc: Option<String>

trans_eff documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

ess_to_fuel_ok_error_doc: Option<String>

ess_to_fuel_ok_error documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

fc_peak_eff_override_doc: Option<String>

fc_peak_eff_override documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

mc_peak_eff_override_doc: Option<String>

mc_peak_eff_override documentation – e.g. info about calibration/validation of vehicle, links to reports or other long-form documentation.

doc: Option<String>

Vehicle level documentation – e.g. info about calibration/validation of this parameter, links to reports or other long-form documentation.

Implementations

source

impl RustVehicle

RustVehicle rust methods

source

pub fn set_veh_mass(&mut self)

Sets the following parameters:

  • ess_mass_kg
  • mc_mass_kg
  • fc_mass_kg
  • fs_mass_kg
  • veh_kg
  • max_trac_mps2
source

pub fn max_regen_kwh(&self) -> f64

source

pub fn mc_peak_eff(&self) -> f64

source

pub fn max_fc_eff_kw(&self) -> f64

Returns first FC output power at which peak efficiency occurs

source

pub fn fc_peak_eff(&self) -> f64

source

pub fn set_mc_peak_eff(&mut self, new_peak: f64)

source

pub fn set_fc_peak_eff(&mut self, new_peak: f64)

source

pub fn set_derived(&mut self) -> Result<(), Error>

Sets derived parameters:

  • no_elec_sys
  • no_elec_aux
  • fc_perc_out_array
  • input_kw_out_array
  • fc_kw_out_array
  • fc_eff_array
  • modern_diff
  • large_baseline_eff_adj
  • mc_kw_adj_perc
  • mc_eff_map
  • mc_eff_array
  • mc_perc_out_array
  • mc_kw_out_array
  • mc_full_eff_array
  • mc_kw_in_array
  • mc_max_elec_in_kw
  • set_fc_peak_eff()
  • set_mc_peak_eff()
  • set_veh_mass()
    • ess_mass_kg
    • mc_mass_kg
    • fc_mass_kg
    • fs_mass_kg
    • veh_kg
    • max_trac_mps2
source

pub fn mock_vehicle() -> Self

source

pub fn from_json_str(filename: &str) -> Result<Self, Error>